function [ E ] = odraz_koryto( d_od2,E0,f,R ) 
% VSTUP: d_od2  - delka paprsku odrazeneho od koryta
%        E0     - pocatecni intenzita pole
%        f      - frekvence vlny [MHz]
%        R      - koeficient odrazu pro koryto
vln=((3*10^(8))/(f*10^(6)));
k=((2*pi())/(vln));
if d_od2==0
    E=0;
else
    E=((E0/d_od2)*exp(-1i*k*d_od2))*(R*exp(-1i*pi()));
end
% VYSTUP: intenzita odrazene vlny od steny koryta v miste jejiho prijeti
%         lodni antenou
end